@@ -1,4 +1,6 @@
 """
+MIT License
+
 Copyright (c) 2021-2022 Yilmaz Alpaslan
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -326,4 +328,7 @@ class Client:
         except Exception:
             pass
         finally:
-            logger.info("Perspective API text analysis has been completed. Request took {:.2f} seconds to process. The attribute with highest score value is {} with a score value of {:.2f}.".format(time.time() - start_timestamp, utils.get_highest(result), result[utils.get_highest(result)]))
+            try:
+                logger.info("Perspective API text analysis has been completed. Request took {:.2f} seconds to process. The attribute with highest score value is {} with a score value of {:.2f}.".format(time.time() - start_timestamp, utils.get_highest(result), result[utils.get_highest(result)]))
+            except EmptyResponse:
+                logger.info("Perspective API text analysis has been completed. Request took {:.2f} seconds to process. However, the response was empty because none of the requested attributes support the language of the text entered.".format(time.time() - start_timestamp))
\ No newline at end of file
